<!DOCTYPE html>
<html>
<head>
<meta charset="UTF-8">
<meta http-equiv="refresh" content="0; URL='{{success_url}}'" />
<title>Redirecting...</title>
</head>

<body>
    <p>This page has moved to <a href="{{success_url}}">{{success_url}}</a>.</p> 
</body>

</html>
