# Generated by Django 2.1 on 2018-08-11 18:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('spgateway', '0002_generate_slug_for_none'),
    ]

    operations = [
        migrations.AlterField(
            model_name='spgatewaycustomerresponseinfo',
            name='Amt',
            field=models.IntegerField(verbose_name='交易金額'),
        ),
        migrations.AlterField(
            model_name='spgatewaynotifyresponsecredit',
            name='Inst',
            field=models.IntegerField(verbose_name='分期-期別'),
        ),
        migrations.AlterField(
            model_name='spgatewaynotifyresponsecredit',
            name='InstEach',
            field=models.IntegerField(verbose_name='分期-每期金額'),
        ),
        migrations.AlterField(
            model_name='spgatewaynotifyresponsecredit',
            name='InstFirst',
            field=models.IntegerField(verbose_name='分期-首期金額'),
        ),
        migrations.AlterField(
            model_name='spgatewaynotifyresponsecredit',
            name='RedAmt',
            field=models.IntegerField(null=True, verbose_name='紅利折抵後實際金額'),
        ),
        migrations.AlterField(
            model_name='spgatewaynotifyresponsecredit',
            name='TokenUseStatus',
            field=models.IntegerField(verbose_name='信用卡快速結帳使用狀態'),
        ),
        migrations.AlterField(
            model_name='spgatewaynotifyresponseinfo',
            name='Amt',
            field=models.IntegerField(verbose_name='交易金額'),
        ),
    ]
