# Generated by Django 2.2.1 on 2019-05-24 02:18

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('estore', '0012_order_spgatewayslug'),
        ('spgateway', '0003_auto_20180811_1809'),
    ]

    operations = [
        migrations.AddField(
            model_name='spgatewaycustomerresponseinfo',
            name='Order',
            field=models.ForeignKey(default=None, on_delete=django.db.models.deletion.CASCADE, to='estore.Order', verbose_name='訂單'),
            preserve_default=False,
        ),
    ]
